/************************************************************************************************
** Project:     FSMGenerator
** Module:	FSMGenerator::examples::Java
** File:	Main_FSMIsEven.java
** Date:        2002.08.01
** Author:      Pavel Bekkerman (chpavel@tx.technion.ac.il)
** Copyright:   Copyright (C) 2002 Pavel Bekkerman
** License:
**             This program is free software; you can redistribute it and/or
**             modify it under the terms of the GNU General Public License as
**             published by the Free Software Foundation; either version 2 of
**             the License, or (at your option) any later version.
**
**             This program is distributed in the hope that it will be useful,
**             but WITHOUT ANY WARRANTY; without even the implied warranty of
**             MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
**             GNU General Public License for more details.
**
**             You should have received a copy of the GNU General Public License
**             along with this program; if not, write to the Free Software
**             Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
**
** Contact:     Pavel Bekkerman (chpavel@tx.technion.ac.il)
************************************************************************************************/

package Main_FSMIsEven;

import FSMApi.*;
import FSMIsEven.*;

public class Main_FSMIsEven
{

  public Main_FSMIsEven()
  {
  }

  public static void main(String[] args)
  {
      FSM fsm = new FSM( new FSMIsEven() );

    try
    {
      fsm.Initialize();
      fsm.Process( IDEvents.EVENT_input0 );
      fsm.Process( IDEvents.EVENT_input1 );
      fsm.Process( IDEvents.EVENT_input0 );
      fsm.Process( IDEvents.EVENT_input1 );
      fsm.Process( IDEvents.EVENT_input0 );
      fsm.Process( IDEvents.EVENT_input1 );
      if( fsm.IsFinal() )
      {
        System.out.println( "Final" );
      }
      else
      {
        System.out.println( "NonFinal" );
      }
      fsm.Finalize();
    }
    catch( FSMException e )
    {
      System.out.println( e );
    }
  }

  public static void Func0()
  {
    System.out.println( "In Func0" );
  }

  public static void Func1()
  {
    System.out.println( "In Func1" );
  }

  public static void Func2()
  {
    System.out.println( "In Func2" );
  }

  public static void Func3()
  {
    System.out.println( "In Func3" );
  }

}
